==> 0.0.54.tar.gz: lib/MenuComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'Constants/ImageAssets.dart';
import 'Constants/AppColors.dart';
import 'Constants/AppStrings.dart';
import 'package:shared_preferences/shared_preferences.dart';

class MenuComponent extends StatefulWidget {
  final KFDrawerController drawerController;
  final Function() signOutFunction;
  final String versionName;

  Widget logo;

  List<Color> color;

  MenuComponent({
    Key key,
    @required this.drawerController,
    @required this.signOutFunction,
    @required this.versionName,
    @required this.logo,
    @required this.color,
  }) : super(key: key);

  @override
  MenuComponentState createState() => MenuComponentState();
}

class MenuComponentState extends State<MenuComponent>
    with TickerProviderStateMixin {
  //KFDrawerController _drawerController;

  static List<Color> color;

  @override
  void initState() {
    super.initState();
    getStringValuesSF();
  }

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        color = [Color(colorCodeInt), AppColors.APP_COLOR_WHITE];
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: KFDrawer(
        controller: widget.drawerController,
        header: Align(
          alignment: Alignment.centerLeft,
          child: Container(
            padding: EdgeInsets.symmetric(horizontal: 16.0),
            width: MediaQuery.of(context).size.width * 0.4,
            child: Column(
              children: [
                widget.logo ??
                    Image.asset(
                      ImageAssets.GMAIL,
                      alignment: Alignment.centerLeft,
                    ),
              ],
            ),
          ),
        ),
        footer: KFDrawerItem(
          text: Column(
            children: [
              Text(
                AppStrings.SIGN_OUT,
                style: TextStyle(color: Colors.white),
              ),
              SizedBox(
                height: 20,
              ),
              Text(
                widget.versionName,
                style: TextStyle(color: Colors.white),
              ),
            ],
          ),
          icon: Column(
            children: [
              Icon(
                Icons.input,
                color: Colors.white,
              ),
              SizedBox(
                height: 35,
              ),
            ],
          ),
          onPressed: () {
            widget.signOutFunction();
          },
        ),
        decoration: BoxDecoration(
          gradient: LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: color != null
                ? color
                : [AppColors.APP_COLOR_PRIMARY, AppColors.APP_COLOR_WHITE],
            tileMode: TileMode.repeated,
          ),
        ),
      ),
    );
  }
}

==> 0.0.63.tar.gz: lib/MenuComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'Constants/ImageAssets.dart';
import 'Constants/AppColors.dart';
import 'Constants/AppStrings.dart';
import 'package:shared_preferences/shared_preferences.dart';

class MenuComponent extends StatefulWidget {
  final KFDrawerController drawerController;
  final Function() signOutFunction;
  final String versionName;

  Widget logo;

  List<Color> color;

  MenuComponent({
    Key key,
     this.drawerController,
     this.signOutFunction,
     this.versionName,
     this.logo,
     this.color,
  }) : super(key: key);

  @override
  MenuComponentState createState() => MenuComponentState();
}

class MenuComponentState extends State<MenuComponent>
    with TickerProviderStateMixin {
  //KFDrawerController _drawerController;

  static List<Color> color;

  @override
  void initState() {
    super.initState();
    getStringValuesSF();
  }

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        color = [Color(colorCodeInt), AppColors.APP_COLOR_WHITE];
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: KFDrawer(
        controller: widget.drawerController,
        header: Align(
          alignment: Alignment.centerLeft,
          child: Container(
            padding: EdgeInsets.symmetric(horizontal: 16.0),
            width: MediaQuery.of(context).size.width * 0.4,
            child: Column(
              children: [
                widget.logo ??
                    Image.asset(
                      ImageAssets.GMAIL,
                      alignment: Alignment.centerLeft,
                    ),
              ],
            ),
          ),
        ),
        footer: KFDrawerItem(
          text: Column(
            children: [
              Text(
                AppStrings.SIGN_OUT,
                style: TextStyle(color: Colors.white),
              ),
              SizedBox(
                height: 20,
              ),
              Text(
                widget.versionName,
                style: TextStyle(color: Colors.white),
              ),
            ],
          ),
          icon: Column(
            children: [
              Icon(
                Icons.input,
                color: Colors.white,
              ),
              SizedBox(
                height: 35,
              ),
            ],
          ),
          onPressed: () {
            widget.signOutFunction();
          },
        ),
        decoration: BoxDecoration(
          gradient: LinearGradient(
            begin: Alignment.topLeft,
            end: Alignment.bottomRight,
            colors: color != null
                ? color
                : [AppColors.APP_COLOR_PRIMARY, AppColors.APP_COLOR_WHITE],
            tileMode: TileMode.repeated,
          ),
        ),
      ),
    );
  }
}
